@@ -71,7 +71,9 @@ class Filter_Text
   private $standardContentMarkerCrossReference;
   
   public $html_text_standard; // Object for creating Web document with text in standard form.
+  public $html_text_linked; // Object for creating Linked web document.
   
+  public $onlinebible_text; // Object for creating the input file for the Online Bible compiler.
   
   /**
   * Class constructor.
@@ -100,6 +102,8 @@ class Filter_Text
     $this->standardContentMarkerFootEndNote = "";
     $this->standardContentMarkerCrossReference = "";
     $this->html_text_standard = new Html_Text (gettext ("Bible"));
+    $this->html_text_linked = new Html_Text (gettext ("Bible"));
+    $this->onlinebible_text = new Onlinebible_Text ();
   }
   
 
@@ -357,6 +361,11 @@ class Filter_Text
   */
   private function processUsfm ()
   {
+    // The linked web file starts with a link back to the index.
+    $this->html_text_linked->newParagraph ();
+    $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement,  "index.html", "", gettext ("Index"), "", gettext ("Index"));
+
+    // Go through the USFM code.
     $processedBooksCount = 0;
     $this->usfmMarkersAndTextPointer = 0;
     while ($this->unprocessedUsfmCodeAvailable ()) {
@@ -381,6 +390,7 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
                 switch ($style['subtype']) 
                 {
                   case IdentifierSubtypeBook:
@@ -402,11 +412,22 @@ class Filter_Text
                         $this->odf_text_text_only->newPageBreak ();
                         $this->odf_text_text_and_note_citations->newPageBreak ();
                         $this->html_text_standard->newPageBreak ();
+                        $this->html_text_linked->newPageBreak ();
                       }
                     }
                     $processedBooksCount++;
-                    // Reset.
+                    // Reset notes.
                     $this->resetNoteCitations ('book');
+                    // Online Bible.
+                    $this->onlinebible_text->storeData ();
+                    // Linked web: Links to all the chapters, and back to the start. Todo
+                    $this->html_text_linked->newParagraph ();
+                    $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement, "", "start", "", "", "");
+                    $this->html_text_linked->addText (gettext ("Chapter") . " |");
+                    for ($i = 1; $i <= $this->numberOfChaptersPerBook[$this->currentBookIdentifier]; $i++) {
+                      $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement, "#chapter$i", "", "Chapter $i", "", " $i |");
+                    }
+                    // Done.
                     break;
                   }
                   case IdentifierSubtypeEncoding:
@@ -491,6 +512,7 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
                 switch ($style['subtype']) 
                 {
                   case ParagraphSubtypeMainTitle:
@@ -516,27 +538,35 @@ class Filter_Text
                   $this->odf_text_text_only->openTextStyle ($style);
                   $this->odf_text_text_and_note_citations->openTextStyle ($style);
                   $this->html_text_standard->openTextStyle ($style);
+                  $this->html_text_linked->openTextStyle ($style);
                 } else {
                   $this->odf_text_standard->closeTextStyle ();
                   $this->odf_text_text_only->closeTextStyle ();
                   $this->odf_text_text_and_note_citations->closeTextStyle ();
                   $this->html_text_standard->closeTextStyle ();
+                  $this->html_text_linked->closeTextStyle ();
                 }
                 break;
               }
-              case StyleTypeChapterNumber:
+              case StyleTypeChapterNumber: // Todo
               {
                 $this->odf_text_standard->closeTextStyle ();
                 $this->odf_text_text_only->closeTextStyle ();
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
+                
+                $this->onlinebible_text->storeData ();
+
                 // Get the chapter number.
                 $number = Filter_Usfm::getTextFollowingMarker ($this->chapterUsfmMarkersAndText, $this->chapterUsfmMarkersAndTextPointer);
                 $number = Filter_Numeric::integer_in_string ($number);
+
                 // Update this object.
                 $this->currentChapterNumber = $number;
                 $this->currentVerseNumber = "0";
+
                 // If there is a published chapter character, the chapter number takes that value.
                 foreach ($this->publishedChapterMarkers as $publishedChapterMarker) {
                   if ($publishedChapterMarker['book'] == $this->currentBookIdentifier) {
@@ -545,6 +575,7 @@ class Filter_Text
                     }
                   }
                 }
+
                 // Enter text for the running headers.
                 $database_books = Database_Books::getInstance ();
                 $runningHeader = $database_books->getEnglishFromId ($this->currentBookIdentifier);
@@ -558,6 +589,12 @@ class Filter_Text
                 $this->odf_text_text_only->newHeading1 ($runningHeader, true);
                 $this->odf_text_text_and_note_citations->newHeading1 ($runningHeader, true);
                 $this->odf_text_notes->newHeading1 ($runningHeader, false);
+                
+                // In the linked web version, each chapter number gets linked to, and links to, the start of the book. Todo
+                $this->html_text_linked->newParagraph ();
+                $hrefId = "chapter" . $this->currentChapterNumber;
+                $this->html_text_linked->addLink ($this->html_text_linked->currentPDomElement, "#start", $hrefId, gettext ("Go to start"), "", gettext ("Go to start"));
+
                 // This is the phase of outputting the chapter number in the text body. 
                 // The chapter number is only output when there is more than one chapter in a book.
                 if ($this->numberOfChaptersPerBook[$this->currentBookIdentifier] > 1) {
@@ -597,16 +634,21 @@ class Filter_Text
                     $this->odf_text_text_only->addText ($number);
                     $this->odf_text_text_and_note_citations->addText ($number);
                     $this->html_text_standard->addText ($number);
+                    $this->html_text_linked->addText ($number);
                   }
                 }
+
                 // Open a paragraph for the notes. It takes the style of the footnote content marker, usually 'ft'. 
                 // This is done specifically for the version that has the notes only.
                 $this->ensureNoteParagraphStyle ($this->standardContentMarkerFootEndNote, $this->styles[$this->standardContentMarkerFootEndNote]);
                 $this->odf_text_notes->newParagraph ($this->standardContentMarkerFootEndNote);
                 // UserBool2ChapterInLeftRunningHeader -> no headings implemented yet.
                 // UserBool3ChapterInRightRunningHeader -> no headings implemented yet.
+
                 // Reset.
                 $this->resetNoteCitations ('chapter');
+                
+                // Done.
                 break;
               }
               case StyleTypeVerseNumber:
@@ -616,6 +658,8 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
+                $this->onlinebible_text->storeData ();
                 // Care for the situation that a new verse starts a new paragraph.
                 if ($style['userbool1']) {
                   if ($this->odf_text_standard->currentParagraphContent != "") {
@@ -630,6 +674,9 @@ class Filter_Text
                   if ($this->html_text_standard->currentParagraphContent != "") {
                     $this->html_text_standard->newParagraph ($this->html_text_standard->currentParagraphStyle);
                   }
+                  if ($this->html_text_linked->currentParagraphContent != "") {
+                    $this->html_text_linked->newParagraph ($this->html_text_linked->currentParagraphStyle);
+                  }
                 }
                 // Deal with the case of a pending chapter number.
                 if (isset ($this->outputChapterTextAtFirstVerse)) {
@@ -646,11 +693,14 @@ class Filter_Text
                   $this->html_text_standard->openTextStyle (array ("marker" => "dropcaps"), false);
                   $this->html_text_standard->addText ($this->outputChapterTextAtFirstVerse);
                   $this->html_text_standard->closeTextStyle ();
+                  $this->html_text_linked->openTextStyle (array ("marker" => "dropcaps"), false);
+                  $this->html_text_linked->addText ($this->outputChapterTextAtFirstVerse);
+                  $this->html_text_linked->closeTextStyle ();
                 }
                 // Temporarily retrieve the text that follows the \v verse marker.
                 $textFollowingMarker = Filter_Usfm::getTextFollowingMarker ($this->chapterUsfmMarkersAndText, $this->chapterUsfmMarkersAndTextPointer);
                 // Extract the verse number, and store it in the object.
-                $number = Filter_Numeric::integer_in_string ($textFollowingMarker);
+                $number = Filter_Usfm::peekVerseNumber ($textFollowingMarker);
                 $this->currentVerseNumber = $number;
                 // Output the verse number. But only if no chapter number was put here.
                 if (!isset ($this->outputChapterTextAtFirstVerse)) {
@@ -667,18 +717,24 @@ class Filter_Text
                   if ($this->html_text_standard->currentParagraphContent != "") {
                     $this->html_text_standard->addText (" ");
                   }
+                  if ($this->html_text_linked->currentParagraphContent != "") {
+                    $this->html_text_linked->addText (" ");
+                  }
                   $this->odf_text_standard->openTextStyle ($style);
                   $this->odf_text_text_only->openTextStyle ($style);
                   $this->odf_text_text_and_note_citations->openTextStyle ($style);
                   $this->html_text_standard->openTextStyle ($style);
+                  $this->html_text_linked->openTextStyle ($style);
                   $this->odf_text_standard->addText ($number);
                   $this->odf_text_text_only->addText ($number);
                   $this->odf_text_text_and_note_citations->addText ($number);
                   $this->html_text_standard->addText ($number);
+                  $this->html_text_linked->addText ($number);
                   $this->odf_text_standard->closeTextStyle ();
                   $this->odf_text_text_only->closeTextStyle ();
                   $this->odf_text_text_and_note_citations->closeTextStyle ();
                   $this->html_text_standard->closeTextStyle ();
+                  $this->html_text_linked->closeTextStyle ();
                 }
                 // If there was any text following the \v marker, remove the verse number, 
                 // put the remainder back into the object, and update the pointer.
@@ -688,12 +744,20 @@ class Filter_Text
                     $textFollowingMarker = substr ($textFollowingMarker, $pos + strlen ($number));
                   }
                   // If a chapter number was put, remove any whitespace from the start of the following text.
-                  if (isset ($this->outputChapterTextAtFirstVerse)) $textFollowingMarker = ltrim ($textFollowingMarker);
+                  // Remove whitespace from the start of the following text, and replace it with the en space.
+                  // This en space is a fixed width space. Having this after the verse number makes things tidier.
+                  // But if a chapter number was put, than do not put any space at the start of the following verse.
+                  $textFollowingMarker = ltrim ($textFollowingMarker);
+                  if (!isset ($this->outputChapterTextAtFirstVerse)) {
+                    $textFollowingMarker = Filter_Character::enSpace () . $textFollowingMarker;
+                  }
                   $this->chapterUsfmMarkersAndText [$this->chapterUsfmMarkersAndTextPointer] = $textFollowingMarker; 
                   $this->chapterUsfmMarkersAndTextPointer--;
                 }
-                // Chapter variable may not have been used, but unset it anyway, making it ready for subsequent use. 
+                // Unset the chapter variable, whether it was used or not. This makes it ready for subsequent use. 
                 unset ($this->outputChapterTextAtFirstVerse);
+                // Online Bible.
+                $this->onlinebible_text->newVerse ($this->currentBookIdentifier, $this->currentChapterNumber, $this->currentVerseNumber);
                 // Done.
                 break;
               }
@@ -714,6 +778,7 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
                 switch ($style['subtype']) 
                 {
                   case PeripheralSubtypePublication:
@@ -741,6 +806,7 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
                 $this->addToFallout ("Picture formatting not yet implemented", true);
                 break;
               }
@@ -751,10 +817,12 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
                 $this->odf_text_standard->newPageBreak ();
                 $this->odf_text_text_only->newPageBreak ();
                 $this->odf_text_text_and_note_citations->newPageBreak ();
                 $this->html_text_standard->newPageBreak ();
+                $this->html_text_linked->newPageBreak ();
                 break;
               }
               case StyleTypeTableElement:
@@ -764,6 +832,7 @@ class Filter_Text
                 $this->odf_text_text_and_note_citations->closeTextStyle ();
                 $this->odf_text_notes->closeTextStyle ();
                 $this->html_text_standard->closeTextStyle ();
+                $this->html_text_linked->closeTextStyle ();
                 switch ($style['subtype']) 
                 {
                   case TableElementSubtypeRow:
@@ -845,6 +914,8 @@ class Filter_Text
           $this->odf_text_text_only->addText ($currentItem);
           $this->odf_text_text_and_note_citations->addText ($currentItem);
           $this->html_text_standard->addText ($currentItem);
+          $this->html_text_linked->addText ($currentItem);
+          $this->onlinebible_text->addText ($currentItem);
         }
       }
     }
@@ -898,8 +969,12 @@ class Filter_Text
                     }
                     // Add the note citation. And a no-break space after it.
                     $this->odf_text_notes->addText ($citation . Filter_Character::noBreakSpace());
-                    // Open note in the web page.
+                    // Open note in the web pages.
                     $this->html_text_standard->addNote ($citation, $this->standardContentMarkerFootEndNote);
+                    $this->html_text_linked->addNote ($citation, $this->standardContentMarkerFootEndNote);
+                    // Online Bible. Footnotes do not seem to behave as they ought in the Online Bible compiler.
+                    // Just take them out, then.
+                    //$this->onlinebible_text->addNote ();
                   } else {
                     break 3;
                   }
@@ -918,6 +993,9 @@ class Filter_Text
                     $this->odf_text_text_and_note_citations->currentTextStyle = $currentTextStyle;
                     // Open note in the web page.
                     $this->html_text_standard->addNote ($citation, $this->standardContentMarkerFootEndNote, true);
+                    $this->html_text_linked->addNote ($citation, $this->standardContentMarkerFootEndNote, true);
+                    // Online Bible.
+                    //$this->onlinebible_text->addNote ();
                   } else {
                     break 3;
                   }
@@ -931,6 +1009,7 @@ class Filter_Text
                   $this->odf_text_standard->closeTextStyle (true);
                   $this->odf_text_notes->closeTextStyle ();
                   $this->html_text_standard->closeTextStyle (true);
+                  $this->html_text_linked->closeTextStyle (true);
                   break;
                 }
                 case FootEndNoteSubtypeContent:
@@ -940,10 +1019,12 @@ class Filter_Text
                     $this->odf_text_standard->openTextStyle ($style, true);
                     $this->odf_text_notes->openTextStyle ($style);
                     $this->html_text_standard->openTextStyle ($style, true);
+                    $this->html_text_linked->openTextStyle ($style, true);
                   } else {
                     $this->odf_text_standard->closeTextStyle (true);
                     $this->odf_text_notes->closeTextStyle ();
                     $this->html_text_standard->closeTextStyle (true);
+                    $this->html_text_linked->closeTextStyle (true);
                   }
                   break;
                 }
@@ -953,6 +1034,7 @@ class Filter_Text
                   $this->odf_text_standard->closeTextStyle (true);
                   $this->odf_text_notes->closeTextStyle ();
                   $this->html_text_standard->closeTextStyle (true);
+                  $this->html_text_linked->closeTextStyle (true);
                   break;
                 }
                 default:
@@ -987,6 +1069,9 @@ class Filter_Text
                     // Open note in the web page.
                     $this->ensureNoteParagraphStyle ($this->standardContentMarkerCrossReference, $this->styles[$this->standardContentMarkerCrossReference]);
                     $this->html_text_standard->addNote ($citation, $this->standardContentMarkerCrossReference);
+                    $this->html_text_linked->addNote ($citation, $this->standardContentMarkerCrossReference);
+                    // Online Bible.
+                    //$this->onlinebible_text->addNote ();
                   } else {
                     break 3;
                   }
@@ -1000,6 +1085,7 @@ class Filter_Text
                   $this->odf_text_standard->closeTextStyle (true);
                   $this->odf_text_notes->closeTextStyle ();
                   $this->html_text_standard->closeTextStyle (true);
+                  $this->html_text_linked->closeTextStyle (true);
                   break;
                 }
                 case CrossreferenceSubtypeContent:
@@ -1009,10 +1095,12 @@ class Filter_Text
                     $this->odf_text_standard->openTextStyle ($style, true);
                     $this->odf_text_notes->openTextStyle ($style);
                     $this->html_text_standard->openTextStyle ($style, true);
+                    $this->html_text_linked->openTextStyle ($style, true);
                   } else {
                     $this->odf_text_standard->closeTextStyle (true);
                     $this->odf_text_notes->closeTextStyle ();
                     $this->html_text_standard->closeTextStyle (true);
+                    $this->html_text_linked->closeTextStyle (true);
                   }
                   break;
                 }
@@ -1038,6 +1126,8 @@ class Filter_Text
         $this->odf_text_standard->addNoteText ($currentItem);
         $this->odf_text_notes->addText ($currentItem);
         $this->html_text_standard->addNoteText ($currentItem);
+        $this->html_text_linked->addNoteText ($currentItem);
+        //$this->onlinebible_text->addText ($currentItem);
       }
     }
     
@@ -1046,6 +1136,8 @@ class Filter_Text
     $this->odf_text_standard->closeCurrentNote ();
     $this->odf_text_notes->closeTextStyle ();
     $this->html_text_standard->closeCurrentNote ();
+    $this->html_text_linked->closeCurrentNote ();
+    //$this->onlinebible_text->closeCurrentNote ();
   }
 
 
@@ -1254,12 +1346,14 @@ class Filter_Text
       $this->odf_text_text_only->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps);
       $this->odf_text_text_and_note_citations->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps);
       $this->html_text_standard->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps);
+      $this->html_text_linked->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps);
       $this->createdOdfStyles [] = $marker;
     }
     $this->odf_text_standard->newParagraph ($marker);
     $this->odf_text_text_only->newParagraph ($marker);
     $this->odf_text_text_and_note_citations->newParagraph ($marker);
     $this->html_text_standard->newParagraph ($marker);
+    $this->html_text_linked->newParagraph ($marker);
   }
   
   
@@ -1428,6 +1522,7 @@ class Filter_Text
       $this->odf_text_text_and_note_citations->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps);
       $this->odf_text_notes->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, 0, 0, 0, 0, 0, $keepWithNext, $dropcaps);
       $this->html_text_standard->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps);
+      $this->html_text_linked->createParagraphStyle ($marker, $fontsize, $italic, $bold, $underline, $smallcaps, $alignment, $spacebefore, $spaceafter, $leftmargin, $rightmargin, $firstlineindent, $keepWithNext, $dropcaps);
       $this->createdOdfStyles [] = $marker;
     }
   }
